PSArchive

Struct PSArchive 

pub struct PSArchive {
    pub version: PSArchiveVersion,
    pub compression: PSArchiveCompression,
    pub table_of_contents: PSArchiveTOC,
    pub manifest: PSArchiveTableItem,
    pub files: Vec<String>,
    pub contents: Vec<PSArchiveTableItem>,
    pub file_size: usize,
}
PSArchive contains all the information about a complete singular Playstation Archive file

Fields

version: PSArchiveVersion

version is the Playstation Archive file version

compression: PSArchiveCompression

compression is the Playstation Archive file compression

table_of_contents: PSArchiveTOC

table_of_contents is the table of contents for the Playstation Archive file

manifest: PSArchiveTableItem

manifest is the manifest file for the Playstation Archive file

files: Vec<String>contents: Vec<PSArchiveTableItem>file_size: usize

Implementations

Source

impl PSArchive

pub fn get_manifest_size_offset(&self) -> (usize, usize)

pub fn get_size_offset(&self, item: usize) -> (usize, usize)

pub fn parse_manifest(&mut self, bytes: impl ConvertAsBytes) -> Vec<String>

pub fn parse_file(&self, item: usize, bytes: impl ConvertAsBytes) -> Vec<u8>